<?php
/**
 * @version     1.0.0
 * @package     com_docebo
 * @copyright   Copyright (C) 2013. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Docebo Srl. <info@docebo.com> - http://www.docebo.com
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * View to edit
 */
class DoceboViewLogin extends JViewLegacy {
	protected $state;
	protected $item;
	protected $form;

	/**
	 * Display the view
	 */
	public function display($tpl = NULL) {
		$this->state = $this->get('State');
		$this->item  = $this->get('Item');
		$this->form  = $this->get('Form');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			throw new Exception(implode("\n", $errors));
		}

		$this->addToolbar();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 */
	protected function addToolbar() {
		JFactory::getApplication()->input->set('hidemainmenu', TRUE);

		$user  = JFactory::getUser();
		$isNew = ($this->item->id == 0);
		if (isset($this->item->checked_out)) {
			$checkedOut = !($this->item->checked_out == 0 || $this->item->checked_out == $user->get('id'));
		} else {
			$checkedOut = FALSE;
		}
		$canDo = DoceboHelper::getActions();

		JToolBarHelper::title(JText::_('COM_DOCEBO_TITLE_LOGIN'), 'login.png');

		// If not checked out, can save the item.
		if (!$checkedOut && ($canDo->get('core.edit') || ($canDo->get('core.create')))) {

			JToolBarHelper::apply('login.apply', 'JTOOLBAR_APPLY');
			JToolBarHelper::save('login.save', 'JTOOLBAR_SAVE');
		}
		if (!$checkedOut && ($canDo->get('core.create'))) {
			//JToolBarHelper::custom('login.save2new', 'save-new.png', 'save-new_f2.png', 'JTOOLBAR_SAVE_AND_NEW', false);
		}
		// If an existing item, can save to a copy.
		if (!$isNew && $canDo->get('core.create')) {
			//JToolBarHelper::custom('login.save2copy', 'save-copy.png', 'save-copy_f2.png', 'JTOOLBAR_SAVE_AS_COPY', false);
		}
		if (empty($this->item->id)) {
			JToolBarHelper::cancel('login.cancel', 'JTOOLBAR_CANCEL');
		} else {
			JToolBarHelper::cancel('login.cancel', 'JTOOLBAR_CLOSE');
		}

	}
}


global $url, $key, $sso, $secret_key, $getset;

class Api extends JViewLegacy {
	static public $totalmembers;

	static public function getSet() {
		$db      = JFactory::getDbo();
		$tPrefix = $db->getPrefix() . 'docebo_general_settings';
		$db->setQuery("SELECT * FROM " . $tPrefix . " Limit 1");
		$general_settings = $db->loadAssoc();

		//print_r($general_settings);
		return $general_settings;
	}

	static public function getHash($params) {
		$getset = self::getSet();
		$key = $getset['api_key'];
		$secret_key = $getset['key'];

		$res =array('sha1'=>'', 'x_auth'=>'');
		$res['sha1']=sha1(implode(',', $params) . ',' . $secret_key);
		$res['x_auth']=base64_encode($key . ':' . $res['sha1']);

		return $res;
	}

	static private function getDefaultHeader($x_auth) {
		$getset = self::getSet();
		$url = $getset['cloud_address'];

		// Get the host/domain from the cloud URL
		$url = str_replace('https://', '', $url);
		$url = str_replace('http://', '', $url);
		$url = parse_url('http://'.$url, PHP_URL_HOST);


		return array( "Host: " . $url, "Content-Type: multipart/form-data", 'X-Authorization: Docebo '.$x_auth);
	}

	static public function call($action, $data_params) {
		$getset = self::getSet();
		$url = trim($getset['cloud_address']);

		$url = str_ireplace('http://', '', $url);
		$url = str_ireplace('https://', '', $url);

		$key = $getset['api_key'];
		$secret_key = $getset['key'];
		$sso = $getset['sso'];
		if (!function_exists('curl_version')) {
			return FALSE;
		}
		$curl = curl_init();
		$hash_info = self::getHash($data_params);
		$http_header =self::getDefaultHeader($hash_info['x_auth']);
		$opt = array(
			CURLOPT_URL=>$url . '/api/' . $action,
			CURLOPT_RETURNTRANSFER=>1,
			CURLOPT_HTTPHEADER=>$http_header,
			CURLOPT_POST=>1,
			CURLOPT_POSTFIELDS=>$data_params,
			CURLOPT_CONNECTTIMEOUT=>5, // Timeout to 5 seconds
			CURLOPT_SSL_VERIFYPEER => FALSE,
			CURLOPT_SSL_VERIFYHOST => FALSE,
		);
		curl_setopt_array($curl, $opt);
		// $output contains the output string
		$output = curl_exec($curl);
		// it closes the session
		curl_close($curl);

		return $output;
	}

	static public function sso($user, $originalUser = FALSE) {
		$getset = self::getSet();
		$url = trim($getset['cloud_address']);
		if (stripos($url, 'http://') === FALSE && stripos($url, 'https://') === FALSE)
			$url = 'http://'.$url;

		$sso = $getset['sso'];

		if($originalUser){
			$username = $user;
		} else {
			// Get the current user's ID so we can get his Docebo username through API
			$user = JFactory::getUser()->get('id');

			$username = Api::userToDoceboUser($user);
		}

		$time = time();
		$token = md5(strtolower($username).','.$time.','.$sso);
		return $url . '/doceboLms/index.php?auth_regen=1&modname=login&op=confirm&login_user=' . urlencode(strtolower($username)) . '&time=' . $time . '&token=' . $token;
	}

	static public function userToDoceboUser($user){

		// Get the Docebo username that is associated
		// with the currently logged in Joomla user
		// (through API)
		$params = array(
			'ext_user' => $user,
			'ext_user_type' => 'wordpress',
		);
		$apiResponse = self::call('user/profile/', $params);
		$docebo_user_info = json_decode($apiResponse);

		if($docebo_user_info && isset($docebo_user_info->userid))
			return $docebo_user_info->userid;

		$user = JFactory::getUser($user);
		if($user){
			return $user->username;
		}

		return FALSE;
	}
}
